Please see [https://docs.mlcommons.org/cm4mlops/scripts/DevOps-automation/set-device-settings-qaic](https://docs.mlcommons.org/cm4mlops/scripts/DevOps-automation/set-device-settings-qaic) for the documentation of this CM script.
